|Travis|_ |Dependency Status|_ |License|_

.. |Travis| image:: https://api.travis-ci.org/itdxer/neupy.png?branch=master
.. _Travis: https://travis-ci.org/itdxer/neupy

.. |Dependency Status| image:: https://dependencyci.com/github/itdxer/neupy/badge
.. _Dependency Status: https://dependencyci.com/github/itdxer/neupy

.. |License| image:: https://img.shields.io/badge/license-MIT-blue.svg
.. _License: https://github.com/itdxer/neupy/blob/master/LICENSE


.. image:: https://github.com/itdxer/neupy/raw/master/site/neupy-logo.png
    :width: 80%
    :align: center


NeuPy v0.6.3
============

NeuPy is a Python library for Artificial Neural Networks. NeuPy supports many different types of Neural Networks from a simple perceptron to deep learning models.

Installation
------------

.. code-block:: bash

    $ pip install neupy

User Guide
----------

* `Install NeuPy <http://neupy.com/pages/installation.html>`_
* Check the `tutorials <http://neupy.com/docs/tutorials.html>`_
* Learn more about NeuPy in the `documentation <http://neupy.com/pages/documentation.html>`_
* Explore lots of different `neural network algorithms <http://neupy.com/pages/cheatsheet.html>`_.
* Read `articles <http://neupy.com/archive.html>`_ and learn more about Neural Networks.

Links
-----

* `Tutorials <http://neupy.com/docs/tutorials.html>`_
* `Documentation <http://neupy.com/pages/documentation.html>`_
* `Articles <http://neupy.com/archive.html>`_
* `Cheat sheet <http://neupy.com/pages/cheatsheet.html>`_
* `Open Issues <https://github.com/itdxer/neupy/issues>`_

Articles
--------

* `Create unique text-style with SOFM <http://neupy.com/2017/12/17/sofm_text_style.html>`_
* `The Art of SOFM <http://neupy.com/2017/12/13/sofm_art.html>`_
* `Self-Organizing Maps and Applications <http://neupy.com/2017/12/09/sofm_applications.html>`_
* `Hyperparameter optimization for Neural Networks  <http://neupy.com/2016/12/17/hyperparameter_optimization_for_neural_networks.html>`_
* `Visualize Backpropagation Algorithms <http://neupy.com/2015/07/04/visualize_backpropagation_algorithms.html>`_
* `MNIST classification <http://neupy.com/2016/11/12/mnist_classification.html>`_
* `Predict prices for houses in the area of Boston <http://neupy.com/2015/07/04/boston_house_prices_dataset.html>`_
* `Password recovery <http://neupy.com/2015/09/21/password_recovery.html>`_
* `Discrete Hopfield Network <http://neupy.com/2015/09/20/discrete_hopfield_network.html>`_
